@@ -1,6 +1,8 @@
 """Strangeworks Qiskit SDK"""
 
-from .VERSION import VERSION as __version__
 import strangeworks
 from .jobs.strangeworksjob import StrangeworksJob
 from .provider import StrangeworksProvider, get_backend
+import importlib.metadata
+
+__version__ = importlib.metadata.version("strangeworks-qiskit")
