@@ -1,4 +1,4 @@
-from strangeworks.qiskit.backends.aws import AwsSimulator
+from strangeworks.qiskit.backends.aws import AwsSimulator, GeneralAWSBackend
 from strangeworks.qiskit.backends.honeywell import HoneywellBackend
 from strangeworks.qiskit.backends.ibm import IBMQBackend, IBMQSimulator
 from strangeworks.qiskit.backends.ionq import IonqBackend
@@ -30,8 +30,6 @@ def backend_resolution(
         if "ionq" in sw_backend_name:
             return IonqBackend
 
-    # only ionq and aspen (rigetti) machines would
-    # currently work with
     if provider == "aws":
         if "ionq" in sw_backend_name.lower():
             return IonqBackend
@@ -44,6 +42,8 @@ def backend_resolution(
         ):
             return AwsSimulator
 
+        return GeneralAWSBackend
+
     if provider == "rigetti":
         return RigettiBackend
 
